<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
<context>
    <name>KWin::MultitaskViewEffect</name>
    <message>
        <source>Drag upwards to remove</source>
        <translation>ئۈستىگە سىيرىپ تازىلاش</translation>
    </message>
    <message>
        <source>No windows</source>
        <translation>كۆزنەك يوق</translation>
    </message>
</context>
</TS>